Class: DNApi::Components::RubyVersion
- Inherits:
-
Object
- Object
- DNApi::Components::RubyVersion
show all
- Defined in:
- lib/dnapi/components/ruby.rb
Constant Summary
collapse
- NAME =
'Ruby'.freeze
- RUBYGEMS_VERSION =
'1.5.2'.freeze
Class Method Summary
collapse
Instance Method Summary
collapse
Instance Method Details
#mysql_adapter ⇒ Object
This shit is used by old versions of cloud_cookbooks and we can’t remove it without breaking the ones that didn’t upgrade.
The latest versions of the cookbooks won’t use this anymore. To know how to specify a database adapter see DNApi::DbStack#adapter_for
44
45
46
|
# File 'lib/dnapi/components/ruby.rb', line 44
def mysql_adapter
'mysql'
end
|
#ruby_flavor ⇒ Object
30
31
32
|
# File 'lib/dnapi/components/ruby.rb', line 30
def ruby_flavor
'dev-lang/ruby'
end
|
#ruby_module ⇒ Object
34
35
36
|
# File 'lib/dnapi/components/ruby.rb', line 34
def ruby_module
'ruby18'
end
|
#ruby_version ⇒ Object
26
27
28
|
# File 'lib/dnapi/components/ruby.rb', line 26
def ruby_version
"#{version}_p#{patch_level}"
end
|
#rubygems_version ⇒ Object
22
23
24
|
# File 'lib/dnapi/components/ruby.rb', line 22
def rubygems_version
self.class::RUBYGEMS_VERSION
end
|